@@ -25,7 +25,7 @@ from json import loads, dumps
 
 from bom.models import Part, PartClass, Subpart, SellerPart, Organization, Manufacturer, ManufacturerPart, User, \
     UserMeta, PartRevision, Assembly, AssemblySubparts
-from bom.forms import PartInfoForm, PartFormSemiIntelligent, PartFormIntelligent, AddSubpartForm, SubpartForm, FileForm, AddSellerPartForm, ManufacturerForm, \
+from bom.forms import PartInfoForm, PartFormSemiIntelligent, PartFormIntelligent, AddSubpartForm, SubpartForm, FileForm, ManufacturerForm, \
     ManufacturerPartForm, SellerPartForm, UserForm, UserMetaForm, UserAddForm, OrganizationForm, OrganizationNumberLenForm, PartRevisionForm, \
     PartRevisionNewForm, PartCSVForm, PartClassForm, PartClassSelectionForm, PartClassCSVForm, UploadBOMForm, BOMCSVForm, PartClassFormSet, \
     OrganizationCreateForm, OrganizationFormEditSettings
@@ -1334,7 +1334,14 @@ def part_revision_delete(request, part_id, part_revision_id):
         return HttpResponseRedirect(reverse('bom:part-info', kwargs={'part_id': part.id}))
 
     part_revision = get_object_or_404(PartRevision, pk=part_revision_id)
+    part = part_revision.part
     part_revision.delete()
+
+    if part.revisions().count() == 0:
+        part.delete()
+        messages.info(request, 'Deleted {}.'.format(part.full_part_number()))
+        return HttpResponseRedirect(reverse('bom:home'))
+
     messages.info(request, 'Deleted {} Rev {}.'.format(part.full_part_number(), part_revision.revision))
 
     return HttpResponseRedirect(reverse('bom:part-info', kwargs={'part_id': part.id}))
